==> aliyun-java-sdk-ecs-4.24.36-sources.jar: com/aliyuncs/ecs/model/v20140526/DeleteDiagnosticMetricSetsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;
import java.util.List;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ecs.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class DeleteDiagnosticMetricSetsRequest extends RpcAcsRequest<DeleteDiagnosticMetricSetsResponse> {
	   

	private List<String> metricSetIdss;
	public DeleteDiagnosticMetricSetsRequest() {
		super("Ecs", "2014-05-26", "DeleteDiagnosticMetricSets");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public List<String> getMetricSetIdss() {
		return this.metricSetIdss;
	}

	public void setMetricSetIdss(List<String> metricSetIdss) {
		this.metricSetIdss = metricSetIdss;	
		if (metricSetIdss != null) {
			for (int i = 0; i < metricSetIdss.size(); i++) {
				putQueryParameter("MetricSetIds." + (i + 1) , metricSetIdss.get(i));
			}
		}	
	}

	@Override
	public Class<DeleteDiagnosticMetricSetsResponse> getResponseClass() {
		return DeleteDiagnosticMetricSetsResponse.class;
	}

}

==> aliyun-java-sdk-ecs-4.24.63-sources.jar: com/aliyuncs/ecs/model/v20140526/DeleteDiagnosticMetricSetsRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ecs.model.v20140526;

import com.aliyuncs.RpcAcsRequest;
import java.util.List;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ecs.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class DeleteDiagnosticMetricSetsRequest extends RpcAcsRequest<DeleteDiagnosticMetricSetsResponse> {
	   

	private List<String> metricSetIdss;
	public DeleteDiagnosticMetricSetsRequest() {
		super("Ecs", "2014-05-26", "DeleteDiagnosticMetricSets", "ecs");
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public List<String> getMetricSetIdss() {
		return this.metricSetIdss;
	}

	public void setMetricSetIdss(List<String> metricSetIdss) {
		this.metricSetIdss = metricSetIdss;	
		if (metricSetIdss != null) {
			for (int i = 0; i < metricSetIdss.size(); i++) {
				putQueryParameter("MetricSetIds." + (i + 1) , metricSetIdss.get(i));
			}
		}	
	}

	@Override
	public Class<DeleteDiagnosticMetricSetsResponse> getResponseClass() {
		return DeleteDiagnosticMetricSetsResponse.class;
	}

}
